@@ -383,7 +383,9 @@ void burn_disc_erase(struct burn_drive *drive, int fast)
 	/* ts A70909 : the willingness to burn any BURN_DISC_FULL media is
 	               inappropriate. One would rather need a -force option
 	               Note: keep this in sync with mmc_read_disc_info() */
-	if ((drive->current_profile != 0x0a &&
+	/* ts B10321 : Allowed role 5 to be blanked */
+	if ((drive->drive_role == 1 &&
+	     drive->current_profile != 0x0a &&
 	     drive->current_profile != 0x13 &&
 	     drive->current_profile != 0x14 &&
 	     drive->status != BURN_DISC_FULL)
@@ -392,7 +394,7 @@ void burn_disc_erase(struct burn_drive *drive, int fast)
 	     drive->status != BURN_DISC_APPENDABLE &&
 	     drive->status != BURN_DISC_BLANK)
 	    ||
-	    (drive->drive_role != 1)
+	    (drive->drive_role != 1 && drive->drive_role != 5)
 	   ) {
 		libdax_msgs_submit(libdax_messenger, drive->global_index,
 			0x00020130,
@@ -517,42 +519,6 @@ void burn_disc_format(struct burn_drive *drive, off_t size, int flag)
 			return;
 
 		} 
-		if ((flag & 6) != 6 || (flag & 128)) {
-		    if ((flag & 64) && !(drive->current_feat23h_byte4 & 2)) {
-			if (drive->current_feat23h_byte4 & 1) {
-				libdax_msgs_submit(libdax_messenger,
-					drive->global_index, 0x00020165,
-				   	LIBDAX_MSGS_SEV_WARNING,
-					LIBDAX_MSGS_PRIO_HIGH,
-				      "Drive does not support fast formatting",
-					0, 0);
-				flag &= ~64;
-			} else {
-no_non_default_bd_re:;
-				libdax_msgs_submit(libdax_messenger,
-					drive->global_index, 0x00020167,
-				   	LIBDAX_MSGS_SEV_SORRY,
-					LIBDAX_MSGS_PRIO_HIGH,
-				"Drive does not support non-default formatting",
-					0, 0);
-				drive->cancel = 1;
-				return;
-			}
-		    }
-		    if ((!(flag & 64)) && !(drive->current_feat23h_byte4 & 1)){
-			if (drive->current_feat23h_byte4 & 2) {
-				libdax_msgs_submit(libdax_messenger,
-					drive->global_index, 0x00020166,
-				   	LIBDAX_MSGS_SEV_WARNING,
-					LIBDAX_MSGS_PRIO_HIGH,
-				      "Drive does not support full formatting",
-					0, 0);
-				flag |= 64;
-			} else
-				goto no_non_default_bd_re;
-		    }
-		}
-
 	}
 
 	if (!ok) {
@@ -659,6 +625,14 @@ void burn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 			"Drive is a virtual placeholder (null-drive)", 0, 0);
 		return;
 	}
+	if (d->drive_role == 4) {
+		libdax_msgs_submit(libdax_messenger, d->global_index,
+			0x00020181,
+			LIBDAX_MSGS_SEV_FAILURE, LIBDAX_MSGS_PRIO_HIGH,
+			"Pseudo-drive is a read-only file. Cannot write.",
+			0, 0);
+		return;
+	}
 
 	/* ts A61007 : obsolete Assert in spc_select_write_params() */
 	if (d->drive_role == 1 && d->mdata->valid <= 0) {
