@@ -240,6 +240,7 @@ LIBJTE_MISCONFIGURATION_ = 0;
    sprintf(msg+strlen(msg), "Cannot initialize libburn\n");
    return(0);
  }
+
  burn_version(&major, &minor, &micro);
  sprintf(msg+strlen(msg), "libburn-%d.%d.%d ", major, minor, micro);
  if(major > burn_header_version_major
@@ -343,7 +344,8 @@ int isoburn_is_intermediate_dvd_rw(struct burn_drive *d, int flag)
 static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
                                  int flag)
 {
- int ret, lba, nwa, profile, readonly= 0;
+ int ret, lba, nwa, profile, readonly= 0, role, random_access;
+ int emulation_started= 0;
  struct burn_multi_caps *caps= NULL;
  struct isoburn_toc_entry *t;
  char profile_name[80];
@@ -382,16 +384,18 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
  (*o)->fabricated_disc_status= BURN_DISC_APPENDABLE;
 #endif
 
- if(caps->start_adr)
+ role= burn_drive_get_drive_role(d);
+ random_access= caps->start_adr || role == 4;
+ if(random_access)
    (*o)->emulation_mode= 1;
- if(caps->start_adr && !readonly) {       /* set emulation to overwriteable */
+ if(random_access && !readonly) {       /* set emulation to overwriteable */
    ret= isoburn_is_intermediate_dvd_rw(d, 0);
    if(ret>0) {
      (*o)->min_start_byte= 0;
      (*o)->nwa= 0;
      (*o)->zero_nwa= 0;
    }
-   if(flag&1) {
+   if((flag & 1) && role != 4 && role != 5) {
      (*o)->nwa= (*o)->zero_nwa;
      (*o)->fabricated_disc_status= BURN_DISC_BLANK;
    } else {
@@ -400,6 +404,7 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
        (*o)->emulation_mode= -1;
        goto ex;
      }
+     emulation_started= 1;
      /* try to read emulated toc */
      ret= isoburn_emulate_toc(d, flag & 16);
      if(ret<0) {
@@ -440,6 +445,12 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
      if((flag & 16) || track_count >= 2) {
        ret= 0; /* toc emulation off, or not overwriteable */
      } else {
+       ret= isoburn_start_emulation(*o, 1);
+       if(ret<=0) {
+         (*o)->emulation_mode= -1;
+         goto ex;
+       }
+       emulation_started= 1;
        ret= isoburn_emulate_toc(d, 1);
        if(ret<0)
          goto ex;
@@ -452,6 +463,13 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
           CD-R TOC (profile 0x08) can be trusted. Others not.
           Do a scan search of ISO headers.
        */
+       if(!emulation_started) {
+         ret= isoburn_start_emulation(*o, 1);
+         if(ret<=0) {
+           (*o)->emulation_mode= -1;
+           goto ex;
+         }
+       }
        ret= isoburn_emulate_toc(d, 1|2);
        if(ret<0)
          goto ex;
@@ -635,7 +653,7 @@ int isoburn_disc_erasable(struct burn_drive *d)
 
 void isoburn_disc_erase(struct burn_drive *drive, int fast)
 {
- int ret, do_pseudo_blank= 0;
+ int ret, do_pseudo_blank= 0, role;
  struct isoburn *o;
  enum burn_disc_status s;
  char zero_buffer[Libisoburn_target_head_sizE];
@@ -648,7 +666,15 @@ void isoburn_disc_erase(struct burn_drive *drive, int fast)
      burn_drive_cancel(drive);
      goto ex;
    }
-
+   role = burn_drive_get_drive_role(drive);
+   if (role == 5) {
+     /* libburn will truncate the random-access write-only file
+        to zero size and change its state */
+     burn_disc_erase(drive, fast);
+     o->fabricated_disc_status= burn_disc_get_status(drive);
+     o->nwa= 0;
+     goto ex;
+   }
    if(o->emulation_mode > 0) { /* might be readonly with emulated sessions */
      ret= burn_disc_get_multi_caps(drive, BURN_WRITE_NONE, &caps, 0);
      if(ret > 0 && caps->start_adr)
@@ -780,6 +806,29 @@ int isoburn_get_msc2(struct isoburn *o,
  return(1);
 }
 
+/* @param flag bit0= truncate (else do not truncate)
+               bit1= do not warn if call is inappropriate to drive 
+               bit2= only set if truncation is currently enabled
+*/
+int isoburn_set_truncate(struct burn_drive *drive, int flag)
+{
+ int ret;
+ struct isoburn *o;
+
+ ret= isoburn_find_emulator(&o, drive, 0);
+ if(ret < 0)
+   return ret;
+ if(o == NULL) {
+   if(!(flag & (2 | 4)))
+     isoburn_msgs_submit(o, 0x00060000,
+        "Drive type or role is inappropriate for truncation", 0, "WARNING", 0);
+   return(0);
+ }
+ if(o->truncate || !(flag & 4))
+   o->truncate= flag & 1;
+ return(1);
+}
+
 
 void isoburn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 {
@@ -828,7 +877,6 @@ void isoburn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
          return;
        }
        /* end of DVD-RW oriented check */
-
        burn_write_opts_set_start_byte(opts, nwa * (off_t) 2048);
      }
    }
@@ -860,7 +908,7 @@ void isoburn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 
  if(o->truncate) {
    ret= burn_drive_get_drive_role(drive);
-   if(ret==2) {
+   if(ret == 2 || ret == 5) {
      ret= burn_drive_d_get_adr(drive, adr);
      if(ret>0) {
        ret= lstat(adr, &stbuf);
@@ -1142,21 +1190,28 @@ int isoburn_read_iso_head(struct burn_drive *d, int lba,
  unsigned char buffer[64*1024];
  int ret, info_mode, capacity, role;
  off_t data_count, to_read;
+ enum burn_disc_status s;
 
  info_mode= flag&255;
  *image_blocks= 0;
  if(flag&(1<<13)) {
    memcpy(buffer, info, 64*1024);
  } else {
+   memset(buffer, 0, 64 * 1024);
+   s= isoburn_disc_get_status(d);
    role = burn_drive_get_drive_role(d);
+   if (role == 3 || role == 5)
+
+     /* >>> ??? return always 0 ? */
+     return(-1*!!(flag&(1<<15)));
+
    ret = burn_get_read_capacity(d, &capacity, 0);
-   if (ret <= 0 && role == 2) {
+   if (ret <= 0 && (role == 2 || role == 4)) {
      /* Might be a block device on a system where libburn cannot determine its
         size.  Try to read anyway. */
      capacity = 0x7ffffff0;
      ret = 1;
    }
-   memset(buffer, 0, 64 * 1024);
    to_read= (off_t) capacity * ((off_t) 2048);
    if(ret > 0 && to_read >= (off_t) (36 * 1024)) {
      if(to_read >= (off_t) (64 * 1024))
@@ -1242,15 +1297,16 @@ int isoburn_emulate_toc(struct burn_drive *d, int flag)
 
  ret= burn_get_read_capacity(d, &readable_blocks, 0);
  if(ret <= 0) {
-
    role = burn_drive_get_drive_role(d);
-   if (role == 2)
+   if (role == 2 || role == 4)
      /* Might be a block device on a system where libburn cannot determine its
         size.  Try to read anyway. */
      readable_blocks= 0x7ffffff0; /* try to read anyway */
    else
      readable_blocks= -1;
  }
+ if(o->fabricated_disc_status == BURN_DISC_BLANK)
+   {ret= 0; goto failure;}
 
  start_time= last_pacifier= time(NULL);
  lba= 0;
