@@ -6,7 +6,7 @@
 /*
   libisofs related functions of libisoburn.
 
-  Copyright 2007 - 2010  Vreixo Formoso Lopes <metalpain2002@yahoo.es>
+  Copyright 2007 - 2011  Vreixo Formoso Lopes <metalpain2002@yahoo.es>
                          Thomas Schmitt <scdbackup@gmx.net>
   Provided under GPL version 2 or later.
 */
@@ -439,14 +439,17 @@ static int isoburn_inspect_partition(struct isoburn *o, uint32_t img_size,
     The need for emulation is confirmed already.
     @param o A freshly created isoburn object. isoburn_create_data_source() was
              already called, nevertheless.
+    @param flag bit0= read-only
     @return <=0 error , 1 = success
 */
 int isoburn_start_emulation(struct isoburn *o, int flag)
 {
- int ret, i, capacity = -1, role;
+ int ret, i, capacity = -1, role, dummy;
  off_t data_count, to_read;
  struct burn_drive *drive;
  struct ecma119_pri_vol_desc *pvm;
+ enum burn_disc_status s;
+ char path[BURN_DRIVE_ADR_LEN], msg[2 * BURN_DRIVE_ADR_LEN];
  
  if(o==NULL) {
    isoburn_msgs_submit(NULL, 0x00060000,
@@ -457,6 +460,9 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
 
  drive= o->drive;
 
+ if(flag & 1)
+   o->fabricated_disc_status= BURN_DISC_FULL;
+
  /* We can assume 0 as start block for image.
     The data there point to the most recent session.
  */
@@ -464,7 +470,12 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
  ret = burn_get_read_capacity(drive, &capacity, 0);
  if (ret <= 0)
    capacity = -1;
- if (capacity > 0 || role == 2) {
+ if (role == 5) { /* random access write-only media */
+   s = burn_disc_get_status(drive);
+   o->fabricated_disc_status= s;
+   burn_disc_track_lba_nwa(drive, NULL, 0, &dummy, &(o->nwa));
+   return 1;
+ } else if (capacity > 0 || role == 2 || role == 4) {
    /* Might be a block device on a system where libburn cannot determine its
       size.  Try to read anyway. */
    to_read = o->target_iso_head_size;
@@ -472,18 +483,25 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
    if(capacity > 0 && (off_t) capacity * (off_t) 2048 < to_read)
      to_read = (off_t) capacity * (off_t) 2048;
    ret = burn_read_data(drive, (off_t) 0, (char*)o->target_iso_head, 
-                        to_read, &data_count, 2);
+                        to_read, &data_count, 2 | 8);
    if (ret <= 0) {
      /* an error means a disc with no ISO image */
-     if (capacity > 0)
+     if (ret == -2) {
+       path[0]= 0;
+       burn_drive_d_get_adr(drive, path);
+       sprintf(msg, "Pseudo drive '%s' does not allow reading", path);
+       isoburn_msgs_submit(NULL, 0x00060000, msg, 0, "NOTE", 0);
+       o->fabricated_disc_status= BURN_DISC_BLANK;
+     } else if (capacity > 0)
        o->fabricated_disc_status= BURN_DISC_FULL;
-     else
-        o->fabricated_disc_status= BURN_DISC_BLANK;
+     else if(!(flag & 1))
+       o->fabricated_disc_status= BURN_DISC_BLANK;
      return 1;
    }
  } else {
    /* No read capacity means blank media */
-   o->fabricated_disc_status= BURN_DISC_BLANK;
+   if(!(flag & 1))
+     o->fabricated_disc_status= BURN_DISC_BLANK;
    return 1;
  }
 
@@ -494,7 +512,8 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
    --i;
 
  if (!i) {
-   o->fabricated_disc_status= BURN_DISC_BLANK;
+   if(!(flag & 1))
+     o->fabricated_disc_status= BURN_DISC_BLANK;
    return 1;
  }
 
@@ -518,12 +537,14 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
      return ret;
    size *= (off_t) 2048; /* block size in bytes */
    isoburn_set_start_byte(o, size, 0);
-   o->fabricated_disc_status= BURN_DISC_APPENDABLE;
+   if(!(flag & 1))
+     o->fabricated_disc_status= BURN_DISC_APPENDABLE;
  } else if (!strncmp((char*)pvm->std_identifier, "CDXX1", 5)) {
 
    /* empty image */
    isoburn_set_start_byte(o, o->zero_nwa * 2048, 0);
-   o->fabricated_disc_status= BURN_DISC_BLANK;
+   if(!(flag & 1))
+     o->fabricated_disc_status= BURN_DISC_BLANK;
  } else {
    /* treat any disc in an unknown format as full */
    o->fabricated_disc_status= BURN_DISC_FULL;
