@@ -11,6 +11,10 @@
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 #include <ctype.h>
 #include <sys/types.h>
 #include <unistd.h>
