@@ -183,6 +183,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->displacement= 0;
  m->displacement_sign= 0;
  m->drives_exclusive= 1;
+ m->early_stdio_test= 0;
  m->do_calm_drive= 1;
  m->indev[0]= 0;
  m->in_drive_handle= NULL;
@@ -306,7 +307,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->errfile_mode= 0;
  m->errfile_fp= NULL;
  
- m->img_read_error_mode= 2;         /* abort faulty image reading with FATAL */
+ m->img_read_error_mode= 1;       /* abort faulty image reading with FAILURE */
  m->extract_error_mode= 1;          /* keep extracted files after read error */
  strcpy(m->return_with_text, "SORRY");
  Xorriso__text_to_sev(m->return_with_text, &m->return_with_severity, 0);
