@@ -166,7 +166,7 @@ int Xorriso_tree_graft_node(struct XorrisO *xorriso, IsoImage *volume,
 {
  int ret, stbuf_valid= 0;
  struct stat stbuf;
- char sfe[5*SfileadrL];
+ char sfe[5*SfileadrL], *namept;
  off_t size= 0;
 
  if(lstat(disk_path, &stbuf) != -1) {
@@ -227,7 +227,12 @@ int Xorriso_tree_graft_node(struct XorrisO *xorriso, IsoImage *volume,
 ex:;
  if(ret<0) {
    Xorriso_process_msg_queues(xorriso,0);
-   Xorriso_report_iso_error(xorriso, nominal_source, ret,
+   if(ret == ISO_RR_NAME_TOO_LONG || ret == ISO_RR_NAME_RESERVED ||
+      ret == ISO_RR_PATH_TOO_LONG)
+     namept= nominal_target;
+   else
+     namept= nominal_source;
+   Xorriso_report_iso_error(xorriso, namept, ret,
                             "Cannot add node to tree", 0, "FAILURE", 1|2);
    return(ret);
  }
