@@ -8,7 +8,7 @@
 
    The conversion rules are described at the beginning of xorriso/xorriso.texi
 
-   Copyright 2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2010 - 2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 */
@@ -229,10 +229,20 @@ int Mx1_convert(struct Mx1 *m, char line_in[256], char line_out[256], int flag)
      }
      strcat(buf, "\\");
    }
+
+   /* Substitute option text */
+   raw= strlen(buf);
    strcat(buf, word);
+   ret= Mx1_substitute(m, buf, line_out, raw, 0);
+   if(ret <= 0)
+     return(-1);
+   strcpy(buf, line_out);
+
    strcat(buf, "\\fR");
    raw= strlen(buf);
    strcat(buf, remainder);
+
+   /* Substitute arguments text */
    ret= Mx1_substitute(m, buf, line_out, raw, 0);
    if(ret <= 0)
      return(-1);
