@@ -148,9 +148,24 @@ int Sfile_add_to_path(char path[SfileadrL], char *addon, int flag)
 
 int Sfile_prepend_path(char *prefix, char path[SfileadrL], int flag)
 {
- int l, i;
+ int l, i, slashes, prefix_len, path_len;
 
- l= strlen(path)+strlen(prefix)+1;
+ l= strlen(prefix);
+ if(l == 0)
+   return(1);
+
+ /* Do not copy slashes between both parts */
+ for(prefix_len= l; prefix_len > 0; prefix_len--)
+   if(prefix[prefix_len - 1] != '/')
+ break;
+ if(prefix_len == 0)
+   prefix_len= strlen(prefix) - 1; 
+ path_len= strlen(path);
+ for(slashes= 0; slashes < path_len; slashes++)
+   if(path[slashes] != '/')
+ break;
+
+ l= (strlen(path) - slashes) + prefix_len + 1;
  if(l>=SfileadrL) {
 
 #ifdef Not_yeT
@@ -164,10 +179,16 @@ int Sfile_prepend_path(char *prefix, char path[SfileadrL], int flag)
    return(-1);
  }
  l-= strlen(path);
- for(i= strlen(path)+1; i>=0; i--)
-   path[i+l]= path[i];
- strcpy(path,prefix);
- path[l-1]= '/';
+ if(l < 0) {
+   for(i= slashes; i <= path_len + 1; i++)
+     path[i+l]= path[i];
+ } else if(l > 0) {
+   for(i= path_len + 1; i >= slashes; i--)
+     path[i+l]= path[i];
+ }
+ if(prefix_len > 0)
+   memcpy(path, prefix, prefix_len);
+ path[l - 1 + slashes]= '/';
  return(1);
 }
 
