@@ -1242,6 +1242,13 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
    Xorriso_status_result(xorriso,filter,fp,flag&2);
  }
 
+ is_default= ((xorriso->early_stdio_test & 14) == 0);
+ sprintf(line, "-early_stdio_test %s\n",
+               xorriso->early_stdio_test & 6 ? xorriso->early_stdio_test & 8 ?
+               "appendable_wo" : "on" : "off");
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso,filter,fp,flag&2);
+
  is_default= (xorriso->allow_restore==0 && xorriso->do_concat_split==1 &&
               xorriso->do_auto_chmod==0 && xorriso->drives_exclusive == 1);
  mode_pt= "off"; 
