@@ -982,7 +982,7 @@ fprintf(stderr, "XORRISO_DEBUG: isoburn_igopt_set_tail_blocks(%d)\n",
  isoburn_sync_after_write(source_drive, drive, 0);
  Xorriso_process_msg_queues(xorriso,0);
 
- sprintf(xorriso->info_text, "Writing to %s completed sucessfully.\n\n",
+ sprintf(xorriso->info_text, "Writing to %s completed successfully.\n\n",
          Text_shellsafe(xorriso->outdev,sfe,0));
  Xorriso_info(xorriso, 0);
  ret= 1;
@@ -1837,7 +1837,7 @@ int Xorriso_burn_track(struct XorrisO *xorriso, off_t write_start_address,
    if(ret <= 0)
      goto ex;
  }
- sprintf(xorriso->info_text, "Writing to %s completed sucessfully.\n\n",
+ sprintf(xorriso->info_text, "Writing to %s completed successfully.\n\n",
          Text_shellsafe(xorriso->outdev,sfe,0));
  Xorriso_info(xorriso, 0);
  ret= 1;
