@@ -111,7 +111,7 @@
 */
 #define Xorriso_req_majoR  1
 #define Xorriso_req_minoR  0
-#define Xorriso_req_micrO  5
+#define Xorriso_req_micrO  6
 
 
 static void yell_xorriso()
@@ -229,7 +229,7 @@ int main(int argc, char **argv)
  */
  ret= Xorriso_prescan_args(xorriso,argc,argv,0);
  if(ret == 0)
-   goto end_sucessfully;
+   goto end_successfully;
  if(ret < 0)
    exit(5);
 
@@ -246,7 +246,7 @@ int main(int argc, char **argv)
  /* Interpret startup files */
  ret= Xorriso_read_rc(xorriso, 0);
  if(ret == 3)
-   goto end_sucessfully;
+   goto end_successfully;
  if(ret <= 0)
    {ret= 5; goto emergency_exit;}
 
@@ -258,7 +258,7 @@ int main(int argc, char **argv)
  i= 1;
  ret= Xorriso_interpreter(xorriso, argc, argv, &i, 2);
  if(ret == 3)
-   goto end_sucessfully;
+   goto end_successfully;
  if(ret <= 0)
    {ret= 5; goto emergency_exit;}
 
@@ -267,7 +267,7 @@ int main(int argc, char **argv)
  if(ret <= 0)
    {ret= 6; goto emergency_exit;}
 
-end_sucessfully:; /* normal shutdown, including eventual -commit */
+end_successfully:; /* normal shutdown, including eventual -commit */
  Xorriso_process_msg_queues(xorriso, 0);
  if(Xorriso_change_is_pending(xorriso, 1))
    Xorriso_option_end(xorriso, 2);
